/*
 * This file is part of the xTuple ERP: PostBooks Edition, a free and
 * open source Enterprise Resource Planning software suite,
 * Copyright (c) 1999-2014 by OpenMFG LLC, d/b/a xTuple.
 * It is licensed to you under the Common Public Attribution License
 * version 1.0, the full text of which (including xTuple-specific Exhibits)
 * is available at www.xtuple.com/CPAL.  By using this software, you agree
 * to be bound by its terms.
 */

#ifndef GLSERIESITEM_H
#define GLSERIESITEM_H

#include "guiclient.h"
#include "xdialog.h"
#include <parameter.h>

#include "ui_glSeriesItem.h"

class glSeriesItem : public XDialog, public Ui::glSeriesItem
{
    Q_OBJECT

public:
    glSeriesItem(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
    ~glSeriesItem();

    virtual void populate();

public slots:
    virtual enum SetResponse set(const ParameterList & pParams );
    virtual void sSave();

protected slots:
    virtual void languageChange();

private:
    int _mode;
    int _glsequence;
    int _glseriesid;
    QString _docnumber;
    QString _doctype;

};

#endif // GLSERIESITEM_H
